@@ -3,6 +3,7 @@ library("SPUTNIK")
 
 ## Mass spectrometry intensity matrix
 X <- matrix(rnorm(200), 20, 40)
+X[X < 0] <- 0
 
 ## Print original dimensions
 print(dim(X))
@@ -17,6 +18,8 @@ imSize <- c(5, 4)
 msiX <- msiDataset(X, mzVector, imSize[1], imSize[2])
 
 ## Determine split peaks
-sp.filter <- splitPeaksFilter(msiData = msiX, mzTolerance = 50,
-                              sharedPixelsRatio = 0,
-                              sparseness = "spatial.chaos", threshold = 0.5)
+sp.filter <- splitPeaksFilter(
+  msiData = msiX, mzTolerance = 50,
+  sharedPixelsRatio = 0,
+  sparseness = "spatial.chaos", threshold = 0.5
+)
